@@ -9,15 +9,15 @@ use feature qw(say);
 use utf8;
 use Data::Dumper;
 use JSON::XS;
-use Time::HiRes  qw(gettimeofday);
-use POSIX        qw(strftime);
+use Time::HiRes qw(gettimeofday);
+use POSIX qw(strftime);
 use Scalar::Util qw(looks_like_number);
-use List::Util   qw(first);
+use List::Util qw(first);
 use Convert::Pheno::SQLite;
 binmode STDOUT, ':encoding(utf-8)';
 use Exporter 'import';
 our @EXPORT =
-  qw(map_ethnicity map_ontology dotify_and_coerce_number iso8601_time _map2iso8601 map_reference_range map_age_range map2redcap_dict map2ohdsi convert2boolean find_age randStr map_operator_concept_id map_info_field map_omop_visit_occurrence dot_date2iso remap_mapping_hash);
+  qw(map_ethnicity map_ontology dotify_and_coerce_number iso8601_time _map2iso8601 map_reference_range map_age_range map2redcap_dict map2ohdsi convert2boolean find_age randStr map_operator_concept_id map_info_field map_omop_visit_occurrence dot_date2iso remap_mapping_hash validate_format);
 
 use constant DEVEL_MODE => 0;
 
@@ -342,7 +342,7 @@ sub map_omop_visit_occurrence {
     my $visit_occurrence    = $self->{visit_occurrence};
 
     # Premature return
-    return undef if $visit_occurrence_id eq '\\N';
+    return undef if $visit_occurrence_id eq '\\N';    # perlcritic Severity: 5
 
 # *** IMPORTANT ***
 # EUNOMIA instance has mismatches between the person_id -- visit_occurrence_id
@@ -356,7 +356,7 @@ sub map_omop_visit_occurrence {
           if DEVEL_MODE;
 
         # Premature return
-        return undef;
+        return undef;    # perlcritic Severity: 5
     }
 
     # Getting pointer to the hash element
@@ -443,4 +443,22 @@ sub remap_mapping_hash {
     return \%hash_out;
 }
 
+sub validate_format {
+
+    my ( $data, $format ) = @_;
+
+    my $result;
+
+    # PXF
+    if ( $format eq 'pxf' ) {
+        $result = exists $data->{subject} ? 1 : 0;
+
+    # BFF
+    }
+    else {
+        $result = !exists $data->{subject} ? 1 : 0;
+    }
+    return $result;
+}
+
 1;
